pub struct MappedRwLockWriteGuard<'a, T>where
T: 'a + ?Sized,{ /* private fields */ }mapped_lock_guards)Expand description
RAII structure used to release the exclusive write access of a lock when dropped, which can point to a subfield of the protected data.
This structure is created by the map and try_map methods
on RwLockWriteGuard.
Implementations
Sourceimpl<'a, T> MappedRwLockWriteGuard<'a, T>where
T: ?Sized,
impl<'a, T> MappedRwLockWriteGuard<'a, T>where
T: ?Sized,
Sourcepub fn map<U, F>(
orig: MappedRwLockWriteGuard<'a, T>,
f: F,
) -> MappedRwLockWriteGuard<'a, U>
🔬This is a nightly-only experimental API. (mapped_lock_guards)
pub fn map<U, F>( orig: MappedRwLockWriteGuard<'a, T>, f: F, ) -> MappedRwLockWriteGuard<'a, U>
mapped_lock_guards)Makes a MappedRwLockWriteGuard for a component of the borrowed data,
e.g. an enum variant.
The RwLock is already locked for writing, so this cannot fail.
This is an associated function that needs to be used as
MappedRwLockWriteGuard::map(...). A method would interfere with
methods of the same name on the contents of the MappedRwLockWriteGuard
used through Deref.
Panics
If the closure panics, the guard will be dropped (unlocked) and the RwLock will be poisoned.
Sourcepub fn try_map<U, F>(
orig: MappedRwLockWriteGuard<'a, T>,
f: F,
) -> Result<MappedRwLockWriteGuard<'a, U>, MappedRwLockWriteGuard<'a, T>>
🔬This is a nightly-only experimental API. (mapped_lock_guards)
pub fn try_map<U, F>( orig: MappedRwLockWriteGuard<'a, T>, f: F, ) -> Result<MappedRwLockWriteGuard<'a, U>, MappedRwLockWriteGuard<'a, T>>
mapped_lock_guards)Makes a MappedRwLockWriteGuard for a component of the borrowed data.
The original guard is returned as an Err(...) if the closure returns
None.
The RwLock is already locked for writing, so this cannot fail.
This is an associated function that needs to be used as
MappedRwLockWriteGuard::try_map(...). A method would interfere with
methods of the same name on the contents of the MappedRwLockWriteGuard
used through Deref.
Panics
If the closure panics, the guard will be dropped (unlocked) and the RwLock will be poisoned.